@@ -72,7 +72,7 @@ def from_file():
     parser = argparse.ArgumentParser(prog ='pythonplus',
                                      description ='Run a Python+ file using the pythonplus command')
     parser.add_argument('filename', metavar ='filename', type=str, nargs=1, help= 'The filename of the file to run using the Python+ Compiler')
-    parser.add_argument('debug', metavar ='d', type=bool, nargs='?', const=False, help= 'Debug the program by showing the converted Python code?')
+    parser.add_argument('debug', metavar ='debug', type=bool, nargs='?', const=False, help= 'Debug the program by showing the converted Python code?')
     args = parser.parse_args()
     try:
         with open(args.filename[0]) as f:
